@@ -33,7 +33,7 @@ from typing import Union, Any, Coroutine, Callable, Optional, Pattern, List
 # cf https://www.imapwiki.org/ClientImplementation/Synchronization
 TWENTY_NINE_MINUTES = 1740.0
 
-STOP_WAIT_SERVER_PUSH = ['stop_wait_server_push']
+STOP_WAIT_SERVER_PUSH = [b'stop_wait_server_push']
 PY37_OR_LATER = sys.version_info[:2] >= (3, 7)
 
 log = logging.getLogger(__name__)
@@ -150,7 +150,7 @@ class Command(object):
 
         self._exception = None
         self._loop = loop if loop is not None else get_running_loop()
-        self._event = asyncio.Event(loop=self._loop)
+        self._event = asyncio.Event()
         self._timeout = timeout
         self._timer = asyncio.Handle(lambda: None, None, self._loop)  # fake timer
         self._set_timer()
@@ -323,7 +323,7 @@ class IMAP4ClientProtocol(asyncio.Protocol):
         self.pending_async_commands = dict()
         self.pending_sync_command = None
         self.idle_queue = asyncio.Queue()
-        self._idle_event = asyncio.Event(loop=loop)
+        self._idle_event = asyncio.Event()
         self.imap_version = None
         self.literal_data = None
         self.incomplete_line = b''
@@ -792,6 +792,9 @@ class IMAP4(object):
     async def rename(self, old_mailbox_name: str, new_mailbox_name: str) -> Response:
         return await asyncio.wait_for(self.protocol.simple_command('RENAME', old_mailbox_name, new_mailbox_name), self.timeout)
 
+    async def getquotaroot(self, mailbox_name: str) -> Response:
+        return await asyncio.wait_for(self.protocol.execute(Command('GETQUOTAROOT', self.protocol.new_tag(), 'INBOX', untagged_resp_name='QUOTA')), self.timeout)
+
     async def list(self, reference_name: str, mailbox_pattern: Pattern) -> Response:
         return await asyncio.wait_for(self.protocol.simple_command('LIST', reference_name, mailbox_pattern), self.timeout)
 
@@ -828,7 +831,7 @@ class IMAP4_SSL(IMAP4):
     def create_client(self, host: str, port: int, loop: asyncio.AbstractEventLoop,
                       conn_lost_cb: Callable[[Optional[Exception]], None] = None, ssl_context: ssl.SSLContext = None) -> None:
         if ssl_context is None:
-            ssl_context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+            ssl_context = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
         super().create_client(host, port, loop, conn_lost_cb, ssl_context)
 
 
